@@ -10,6 +10,7 @@
 #include <QtCore/QCoreApplication>
 #include <QDesktopServices>
 #include <QShortcut>
+#include <QFont>
 #include <QUrl>
 #include <QFile>
 #include <QFileInfo>
@@ -51,9 +52,29 @@ MainWindow::MainWindow(QWidget *parent):
 
     //Set Statusbar Font Size
     QFont f = ui->labelStat->font();
-    f.setPointSize( f.pointSize() + 4 );
+    f.setPointSize( f.pointSize() + 1 );
     QFont g = ui->labelLocStat->font();
-    g.setPointSize( g.pointSize() + 4 );
+    g.setPointSize( g.pointSize() + 1 );
+    QFont t = ui->labelDT->font();
+    t.setPointSize( t.pointSize() - 3 );
+
+    //Set Date Time Text
+   if ( QFileInfo("/tmp/flopswapcur").exists() )
+    {
+        QSettings settings("flopswap", "flopswap");
+        if (settings.contains("LastRefreshDateTime"))
+        {
+          ui->labelDT->setText("Updated: " + settings.value("LastRefreshDateTime").toString());
+        }
+        else
+        {
+          ui->labelDT->setText("");
+        }
+    }
+   else
+    {
+       ui->labelDT->setText("Updated: Never");
+    }
 
     //Set Action Text
     ui->actionSettings->setText(tr("Settings"));
@@ -268,7 +289,8 @@ void MainWindow::disableStatus()
         ui->pushButtonEject->setDisabled(true);
         ui->pushButtonEjectV->setDisabled(true);
         ui->pushButtonGet->setDisabled(true);
-        ui->labelStat->setText("Safe to Remove Back Cover");
+        ui->labelStat->setText("Not Available");
+        ui->labelLocStat->setText("Safe to Remove Back Cover");
    }
  else
    {
@@ -341,6 +363,29 @@ void MainWindow::enableButtons()
     disableStatus();
 }
 
+void MainWindow::ejectclick()
+{
+    QMessageBox msgBox;
+     msgBox.setText("Continue?");
+     msgBox.setWindowTitle("Move Swap to Device");
+     msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+     msgBox.setDefaultButton(QMessageBox::Yes);
+     int ret = msgBox.exec();
+     switch (ret) {
+       case QMessageBox::Yes:
+             ejectshow();
+             m_process->start("sudo /opt/flopswap/script/swapswitchejectsd.sh");
+             ejectseen();
+           break;
+       case QMessageBox::No:
+           // Cancel was clicked
+           break;
+       default:
+           // should never be reached
+           break;
+     }
+}
+
 //Buttons
 void MainWindow::on_pushButtonSwap_clicked()
 { 
@@ -349,21 +394,22 @@ void MainWindow::on_pushButtonSwap_clicked()
 
 void MainWindow::on_pushButtonEject_clicked()
 {
-    ejectshow();
-    m_process->start("sudo /opt/flopswap/script/swapswitchejectsd.sh");
-    ejectseen();
+    ejectclick();
 }
 
 void MainWindow::on_pushButtonEjectV_clicked()
 {
-    ejectshow();
-    m_process->start("sudo /opt/flopswap/script/swapswitchejectsd.sh");
-    ejectseen();
+    ejectclick();
 }
 
 void MainWindow::on_pushButtonGet_clicked()
 {
     m_process->start("sudo /opt/flopswap/script/swapused.sh");
+    QDateTime dateTime = QDateTime::currentDateTime();
+    QString dateTimeString = dateTime.toString();
+    ui->labelDT->setText("Updated: " + dateTimeString);
+    QSettings settings("flopswap", "flopswap");
+    settings.setValue("LastRefreshDateTime", dateTimeString);
 }
 /*
 void MainWindow::on_pushButtonSwapUsage_clicked()
