@@ -4,6 +4,28 @@ source /opt/flopswap/script/setvari.sh
 
 ## Check source file echos.
 echo $swap
+#Print to file
+echo $swap > "$locatetempfile"
+banner "$swap"
+ if [ "$swap" = "$swap1" ] ;
+  then
+    if [ -e $inttempfile ];
+     then
+      rm "$inttempfile"
+    fi
+ elif [ "$swap" = "$swap2" ] ;
+   then
+    if [ -e $inttempfile ];
+     then
+      rm "$inttempfile"
+    fi
+ elif [ "$swap" = "$swap0" ] ;
+  then
+   touch "$inttempfile"
+ else
+  echo "You shouldn't have got here"
+   exit 1
+ fi
 
 ###########
 #Get current swap from /proc/swaps
